database_stein_watkins: Database of elliptic curves (full version)
==================================================================

Description
-----------

The Stein-Watkins database of elliptic curves (full version)

See http://modular.math.washington.edu/papers/stein-watkins/

This is an optional (huge) package, not included by default.

License
-------

Public Domain
